#ifndef SIMPLECALC_H
#define SIMPLECALC_H

void simpleEval();
char *simpleCalc(const unsigned char input, const char *expStr);
void simpleClearEntry();
void simpleClearAll();

#endif
